@@ -44,8 +44,8 @@ class BatteryWatcherSettings : public QWidget
     Q_OBJECT
 
 public:
-    explicit BatteryWatcherSettings(QWidget *parent = 0);
-    ~BatteryWatcherSettings();
+    explicit BatteryWatcherSettings(QWidget *parent = nullptr);
+    ~BatteryWatcherSettings() override;
 
 public slots:
     void loadSettings();
