@@ -286,6 +286,11 @@
         <source>Hibernate Key Action:</source>
         <translation>Acció botó d&apos;hibernació:</translation>
     </message>
+    <message>
+        <location filename="../powerkeyssettings.cpp" line="48"/>
+        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
+        <translation>Nota: amb Wayland, les tecles d&apos;engegada les configura el compositor.</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
