@@ -286,6 +286,11 @@
         <source>Hibernate Key Action:</source>
         <translation>Ενέργεια του πλήκτρου νάρκωσης:</translation>
     </message>
+    <message>
+        <location filename="../powerkeyssettings.cpp" line="48"/>
+        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
+        <translation>Σημείωση: Στο Wayland, τα πλήκτρα τροφοδοσίας διαμορφώνονται από τον συνθέτη.</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
