@@ -36,9 +36,9 @@ public slots:
 
 private:
 
-    QIcon &circleIcon();
-    QIcon buildCircleIcon(Solid::Battery::ChargeState state, int chargeLevel);
-
+    QIcon generatedIcon();
+    template <int iconType>
+        QString buildIcon(Solid::Battery::ChargeState state, int chargeLevel);
 
     int mChargePercent;
     Solid::Battery::ChargeState mState;
